<?php

/*
Plugin Name: Yet Another Social Plugin
Version: 1.1.1
Description: Add social networking share buttons above or below each posts. Easy customization and positioning of the buttons in the Options page.
Author: Marvie Pons
Author URI: http://triptripper.com/
Donate URI: http://triptripper.com/how-to-tutorials/
Plugin URI: http://triptripper.com/how-to-tutorials/yet-another-social-plugin/
  
Copyright 2012  Marvie Pons (email: celebritybanderas@gmail.com)

Released under GPL License.
*/

define('YASP_VERSION', '1.1.1');

// REQUIRE MINIMUM VERSION OF WORDPRESS:
function yasp_requires_wordpress_version() {
	global $wp_version;
	$plugin = plugin_basename( __FILE__ );
	$plugin_data = get_plugin_data( __FILE__, false );

	if ( version_compare($wp_version, "3.0", "<" ) ) {
		if( is_plugin_active($plugin) ) {
			deactivate_plugins( $plugin );
			wp_die( "'".$plugin_data['Name']."' requires WordPress 3.0 or higher, and has been deactivated! Please upgrade WordPress and try again.<br /><br />Back to <a href='".admin_url()."'>WordPress admin</a>." );
		}
	}
}
add_action( 'admin_init', 'yasp_requires_wordpress_version' );

// Set-up Action and Filter Hooks
register_activation_hook(__FILE__, 'yasp_add_defaults');
register_uninstall_hook(__FILE__, 'yasp_delete_plugin_options');
add_action('admin_init', 'yasp_init' );
add_action('admin_menu', 'yasp_add_options_page');
add_filter( 'plugin_action_links', 'yasp_plugin_action_links', 10, 2 );

// Delete options table entries ONLY when plugin deactivated AND deleted
function yasp_delete_plugin_options() {
	delete_option('yasp_options');
}

// Define default option settings
function yasp_add_defaults() {
	$tmp = get_option('yasp_options');
    if(($tmp['chk_default_options_db']=='1')||(!is_array($tmp))) {
		delete_option('yasp_options'); // so we don't have to reset all the 'off' checkboxes too! (don't think this is needed but leave for now)
		$arr = array(	"chek_button1" => "",
						"chk_default_options_db" => "",
						"chk_button1" => ""
		);
		update_option('yasp_options', $arr);
	}
}

// Init plugin options to white list our options
function yasp_init(){
	register_setting( 'yasp_plugin_options', 'yasp_options','yasp_validate_options' );
}

// Add menu page
function yasp_add_options_page() {
	add_options_page('Yet Another Social Plugin', 'YASP', 'manage_options', 'yasp', 'yasp_render_form');
}

// Render the Plugin options form
function yasp_render_form() {
	?>
	<div class="wrap">
		
		<!-- Display Plugin Icon, Header, and Description -->
		<div class="icon32" id="icon-options-general"><br></div>
		<h2>Yet Another Social Plugin v<?php echo YASP_VERSION; ?></h2>
		<p>To easily customize <strong>Yet Another Social Plugin</strong>, use the options below.</p>
	

	<div id="poststuff" class="metabox-holder has-right-sidebar">
	
		<!-- Plugin Options Column -->

		<div id="post-body" class="has-sidebar">
			<div id="post-body-content" class="has-sidebar-content">
				<div id="normal-sortables" class="meta-box-sortables">
					<div id="about" class="postbox">
						<div class="inside">	


		<!-- Beginning of the Plugin Options Form -->
		<form method="post" action="options.php">
			<?php settings_fields('yasp_plugin_options'); ?>
			<?php $options = get_option('yasp_options'); ?>

			<!-- Table Structure Containing Form Controls -->
			<!-- Each Plugin Option Defined on a New Table Row -->
			<table class="form-table">

				<!-- Checkbox Buttons -->
				<tr valign="top">
					<th scope="row">General Options</th>
					<td>
						<!-- First checkbox button -->
						<label><input name="yasp_options[chek_button1]" type="checkbox" value="1" <?php if (isset($options['chek_button1'])) { checked('1', $options['chek_button1']); } ?> /> Check this box to show the buttons before the post</label><br />

						<!-- Second radio button -->
						<label><input name="yasp_options[chk_button1]" type="checkbox" value="1" <?php if (isset($options['chk_button1'])) { checked('1', $options['chk_button1']); } ?> /> Check this box to show box type buttons</label><br />
						
					</td>
				</tr>

				<!-- Textbox Control -->
				<tr>
					<th scope="row">Default Image URL</th>
					<td>
						<input type="text" size="57" name="yasp_options[txt_one]" value="<?php echo $options['txt_one']; ?>" /><span style="color:#666666;margin-left:2px;"><br />Enter full URL including http:// in this box. This image will be pinned if there's not an image in the post.</span>
					</td>
				</tr>	

				<tr><td colspan="2"><div style="margin-top:10px;"></div></td></tr>
				<tr valign="top" style="border-top:#dddddd 1px solid;">
					<th scope="row">Database Options</th>
					<td>
						<label><input name="yasp_options[chk_default_options_db]" type="checkbox" value="1" <?php if (isset($options['chk_default_options_db'])) { checked('1', $options['chk_default_options_db']); } ?> /> Restore defaults upon plugin deactivation/reactivation</label>
						<br /><span style="color:#666666;margin-left:2px;">Only check this if you want to reset plugin settings upon Plugin reactivation</span>
					</td>
				</tr>
			</table>

			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />

		</form>
				
				<br class="clear" />
						</div>
					</div>
				</div>
			</div>
		</div>
		
				<!-- Side Info Column -->
		
			<div id="side-info-column" class="inner-sidebar">
			<div class="meta-box-sortables">
				<div id="about" class="postbox">
					<h3 class="hndle" id="about-sidebar">About the Plugin:</h3>
					<div class="inside">
						<p>You are using <a href="http://triptripper.com/how-to-tutorials/yet-another-social-plugin/" target="_blank" style="color:#72a1c6;"><strong>Yet Another Social Plugin</strong></a> v<?php echo YASP_VERSION; ?></p>
						<p><strong>Enjoy the plugin?</strong><br />				
						Why not consider <a href="http://wordpress.org/extend/plugins/yet-another-social-plugin/" target="_blank">giving it a good rating on WordPress.org</a> or <a href="http://twitter.com/?status=Yet Another Social Plugin for WordPress - check it out! http://triptripper.com/how-to-tutorials/yet-another-social-plugin/" target="_blank">Tweet about it</a>. Thanks.</p>
					</div>
				</div>
			</div>	

			<div id="about" class="postbox">
				<h3 class="hndle" id="about-sidebar">Donate:</h3>
				<div class="inside">
					<p>If you have found this plugin at all useful, please consider buying me a cup of coffee. Thank you!<br />
					<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
					<input type="hidden" name="cmd" value="_s-xclick">
					<input type="hidden" name="hosted_button_id" value="AFRAKJBTHCPYS">
					<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
					<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
					</form></p>
				</div>
			</div>
			</div>

	</div>	
			
	</div>
	<?php	
}

// Sanitize and validate input
function yasp_validate_options($input) {
	if ( ! isset( $input['chk_button1'] ) )
		$input['chk_button1'] = null;
	$input['chk_button1'] = ( $input['chk_button1'] == 1 ? 1 : 0 );
	
	if ( ! isset( $input['chek_button1'] ) )
		$input['chek_button1'] = null;
	$input['chek_button1'] = ( $input['chek_button1'] == 1 ? 1 : 0 );
	
	$input['txt_one'] =  wp_filter_nohtml_kses($input['txt_one']);
	
	return $input;
}

// Display a Settings link on the main Plugins page
function yasp_plugin_action_links( $links, $file ) {

	if ( $file == plugin_basename( __FILE__ ) ) {
		$yasp_links = '<a href="'.get_admin_url().'options-general.php?page=yasp">'.__('Settings').'</a>';
		// make the 'Settings' link appear first
		array_unshift( $links, $yasp_links );
	}

	return $links;
}

// ------------------------------------------------------------------------------
// YASP PLUGIN FUNCTIONS:
// ------------------------------------------------------------------------------


add_filter('the_content', 'yasp_buttons');

function yasp_buttons($content) {
	
	global $post;
	$options = get_option('yasp_options');

	// single posts or pages
	if(is_single() || is_page()){
		
		// get image
		if(function_exists('get_post_thumbnail_id')){
			$catch_thumbs = wp_get_attachment_image_src(get_post_thumbnail_id($post->id), 'large');
			$catch_thumb = $catch_thumbs[0];
		}

		// If there is no featured image or any image, search post for images and display first one. If none exist, display default image
		if($catch_thumb[0] == ''){
				$out = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $match);
				if ( $out > 0 ){
					$catch_thumb = $match[1][0];
				} else {
			$options = get_option('yasp_options');
			$catch_thumb = $options['txt_one'];
			}
		}
		
		
		$excerpt = ""; 
		if (has_excerpt($post->ID)) {
			$excerpt = esc_attr(strip_tags(get_the_excerpt($post->ID)));
		}else{
			$excerpt = esc_attr(str_replace("\r\n",' ',substr(strip_tags(strip_shortcodes($post->post_content)), 0, 100)));
		}		
	}

	
	$yaspvert = '
	<div class="fb-button" style="width: 75px; float: left;">
	<div id="fb-root"></div><script src="http://connect.facebook.net/en_US/all.js#xfbml=1"></script><fb:like href="'.get_permalink($post->id).'" layout="box_count"></fb:like>
	</div>
	<div class="plusone" style="width: 75px; float: left;"><g:plusone size="tall" annotation="bubble" href="'.get_permalink().'"></g:plusone></div>
	<div id="tweet-button" style="width: 90px; float: left;"><a href="http://twitter.com/share" class="twitter-share-button" data-count="vertical">Tweet</a></div>
	<div id="pinterest-wrapper" style="width: 70px; float: left;"><a href="http://pinterest.com/pin/create/button/?url='.get_permalink($post->id).'&media='. $catch_thumb.'&description='.$excerpt.'" class="pin-it-button" count-layout="vertical">Pin It</a></div>
	<div id="linkedin-wrapper"><script type="in/share" data-url="'.get_permalink($post->id).'" data-counter="top"></script></div>
	';
	
	$yasphor = '
	<div class="fb-button" style="width: 75px; float: left;">
	<div id="fb-root"></div><script src="http://connect.facebook.net/en_US/all.js#xfbml=1"></script><fb:like href="'.get_permalink($post->id).'" layout="button_count"></fb:like>
	</div>
	<div class="plusone" style="width: 75px; float: left;"><g:plusone size="medium" annotation="bubble" href="'.get_permalink().'"></g:plusone></div>
	<div id="tweet-button" style="width: 90px; float: left;"><a href="http://twitter.com/share" class="twitter-share-button" data-count="horizontal">Tweet</a></div>
	<div id="pinterest-wrapper" style="width: 70px; float: left;"><a href="http://pinterest.com/pin/create/button/?url='.get_permalink($post->id).'&media='. $catch_thumb.'&description='.$excerpt.'" class="pin-it-button" count-layout="horizontal">Pin It</a></div>
	<div id="linkedin-wrapper"><script type="in/share" data-url="'.get_permalink($post->id).'" data-counter="right"></script></div>
	';
	
	$clearfix = '<div class="yaspclearfix" style="clear: both;"></div>';

	
if(!is_feed() && !is_home()) if ( isset($options['chek_button1']) && ($options['chek_button1']!="") ) 
	{ if ( isset($options['chk_button1']) && ($options['chk_button1']!="") ) {
	$content = $yaspvert.$clearfix.$content;
	}
	else {
	$content = $yasphor.$clearfix.$content;
	}	
} else { if ( isset($options['chk_button1']) && ($options['chk_button1']!="") ) {
	$content = $content.$clearfix.$yaspvert;
	}
	else {
	$content = $content.$clearfix.$yasphor;
	}
}
	return $content;
}

add_action ('wp_enqueue_scripts','yasp_enqueue_script');

function yasp_enqueue_script() {
	wp_enqueue_script('google-plusone', 'https://apis.google.com/js/plusone.js', array(), null, true);
	wp_enqueue_script('linkedin', 'http://platform.linkedin.com/in.js', array(), null, true);
	wp_enqueue_script('pinterest', 'http://assets.pinterest.com/js/pinit.js', array(), null, true);
	wp_enqueue_script('twitter', 'http://platform.twitter.com/widgets.js', array(), null, true);
}

